summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/kernel/tqwidget_x11.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/kernel/tqwidget_x11.cpp
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/kernel/tqwidget_x11.cpp')
-rw-r--r--tqtinterface/qt4/src/kernel/tqwidget_x11.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/tqtinterface/qt4/src/kernel/tqwidget_x11.cpp b/tqtinterface/qt4/src/kernel/tqwidget_x11.cpp
index 0a60833..60df412 100644
--- a/tqtinterface/qt4/src/kernel/tqwidget_x11.cpp
+++ b/tqtinterface/qt4/src/kernel/tqwidget_x11.cpp
@@ -483,7 +483,7 @@ extern bool qt_nograb();
// defined in qapplication_x11.cpp
extern void qt_deferred_map_add( TQWidget* );
extern void qt_deferred_map_take( TQWidget* );
-extern bool qt_deferred_map_tqcontains(TQWidget *);
+extern bool qt_deferred_map_contains(TQWidget *);
static TQWidget *mouseGrb = 0;
static TQWidget *keyboardGrb = 0;
@@ -792,7 +792,7 @@ void TQWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
TQPaintDeviceX11Data* xd = getX11Data( TRUE );
// tqfind which screen the window is on...
xd->x_screen = TQPaintDevice::x11AppScreen(); // by default, use the default :)
int i;
for ( i = 0; i < ScreenCount( dpy ); i++ ) {
@@ -812,7 +812,7 @@ void TQWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
setX11Data( xd );
} else if ( desktop ) { // desktop widget
id = (WId)parentw; // id = root window
- TQWidget *otherDesktop = tqfind( id ); // is there another desktop?
+ TQWidget *otherDesktop = find( id ); // is there another desktop?
if ( otherDesktop && otherDesktop->testWFlags(WPaintDesktop) ) {
otherDesktop->setWinId( 0 ); // remove id from widget mapper
setWinId( id ); // make sure otherDesktop is
@@ -966,7 +966,7 @@ void TQWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
XSetTransientForHint( dpy, id, root_win );
}
// tqfind the real client leader, i.e. a toplevel without tqparent
while ( p && p->parentWidget())
p = p->parentWidget()->tqtopLevelWidget();
@@ -1668,7 +1668,7 @@ void TQWidget::setMouseTracking( bool enable )
else
clearWState( WState_MouseTracking );
if ( testWFlags(WType_Desktop) ) { // desktop widget?
- TQWidget* main_desktop = tqfind( winId() );
+ TQWidget* main_desktop = find( winId() );
if ( main_desktop->testWFlags(WPaintDesktop) )
XSelectInput( x11Display(), winId(),
stdDesktopEventMask | ExposureMask );
@@ -1900,7 +1900,7 @@ TQWidget *TQWidget::keyboardGrabber()
void TQWidget::setActiveWindow()
{
TQWidget *tlw = tqtopLevelWidget();
- if ( tlw->isVisible() && !tlw->topData()->embedded && !qt_deferred_map_tqcontains(tlw) ) {
+ if ( tlw->isVisible() && !tlw->topData()->embedded && !qt_deferred_map_contains(tlw) ) {
XSetInputFocus( x11Display(), tlw->winId(), RevertToNone, GET_QT_X_TIME());
focusInputContext();
}
@@ -1948,8 +1948,8 @@ void TQWidget::update()
Calling update() several times normally results in just one
paintEvent() call.
- If \a w is negative, it is tqreplaced with \c{width() - x}. If \a h
- is negative, it is tqreplaced width \c{height() - y}.
+ If \a w is negative, it is replaced with \c{width() - x}. If \a h
+ is negative, it is replaced width \c{height() - y}.
TQt normally erases the specified area before the paintEvent()
call. If the \c WRepaintNoErase widget flag is set, the widget is
@@ -2007,8 +2007,8 @@ void TQWidget::update( int x, int y, int w, int h )
If \a erase is TRUE, TQt erases the area \a (x, y, w, h) before the
paintEvent() call.
- If \a w is negative, it is tqreplaced with \c{width() - x}, and if
- \a h is negative, it is tqreplaced width \c{height() - y}.
+ If \a w is negative, it is replaced with \c{width() - x}, and if
+ \a h is negative, it is replaced width \c{height() - y}.
We suggest only using tqrepaint() if you need an immediate tqrepaint,
for example during animation. In almost all circumstances update()
@@ -2322,7 +2322,7 @@ void TQWidget::hideWindow()
void TQWidget::raise()
{
TQWidget *p = parentWidget();
- if ( p && p->childObjects && p->childObjects->tqfindRef(this) >= 0 )
+ if ( p && p->childObjects && p->childObjects->findRef(this) >= 0 )
p->childObjects->append( p->childObjects->take() );
XRaiseWindow( x11Display(), winId() );
}
@@ -2339,7 +2339,7 @@ void TQWidget::raise()
void TQWidget::lower()
{
TQWidget *p = parentWidget();
- if ( p && p->childObjects && p->childObjects->tqfindRef(this) >= 0 )
+ if ( p && p->childObjects && p->childObjects->findRef(this) >= 0 )
p->childObjects->insert( 0, p->childObjects->take() );
XLowerWindow( x11Display(), winId() );
}
@@ -2357,9 +2357,9 @@ void TQWidget::stackUnder( TQWidget* w)
TQWidget *p = parentWidget();
if ( !w || isTopLevel() || p != w->parentWidget() || this == w )
return;
- if ( p && p->childObjects && p->childObjects->tqfindRef(w) >= 0 && p->childObjects->tqfindRef(this) >= 0 ) {
+ if ( p && p->childObjects && p->childObjects->findRef(w) >= 0 && p->childObjects->findRef(this) >= 0 ) {
p->childObjects->take();
- p->childObjects->insert( p->childObjects->tqfindRef(w), this );
+ p->childObjects->insert( p->childObjects->findRef(w), this );
}
Window stack[2];
stack[0] = w->winId();;
@@ -2372,7 +2372,7 @@ void TQWidget::stackUnder( TQWidget* w)
/*
The global variable qt_widget_tlw_gravity defines the window gravity of
the next top level window to be created. We do this when setting the
- main widget's tqgeometry and the "-tqgeometry" command line option tqcontains
+ main widget's tqgeometry and the "-tqgeometry" command line option contains
a negative position.
*/
@@ -2645,8 +2645,8 @@ void TQWidget::setBaseSize( int basew, int baseh )
Erases the specified area \a (x, y, w, h) in the widget without
generating a \link paintEvent() paint event\endlink.
- If \a w is negative, it is tqreplaced with \c{width() - x}. If \a h
- is negative, it is tqreplaced width \c{height() - y}.
+ If \a w is negative, it is replaced with \c{width() - x}. If \a h
+ is negative, it is replaced width \c{height() - y}.
Child widgets are not affected.
@@ -792,7 +792,7 @@ void TQWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
TQPaintDeviceX11Data* xd = getX11Data( TRUE );
- // tqfind which screen the window is on...
+ // find which screen the window is on...
xd->x_screen = TQPaintDevice::x11AppScreen(); // by default, use the default :)
int i;
@@ -966,7 +966,7 @@ void TQWidget::create( WId window, bool initializeWindow, bool destroyOldWindow)
XSetTransientForHint( dpy, id, root_win );
}
- // tqfind the real client leader, i.e. a toplevel without tqparent
+ // find the real client leader, i.e. a toplevel without tqparent
while ( p && p->parentWidget())
p = p->parentWidget()->tqtopLevelWidget();